/*******************************************************************************
 * Copyright (C) 2011  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 *******************************************************************************/

package org.ow2.orchestra.designer.server;

import java.io.IOException;
import java.util.logging.Level;
import java.util.logging.Logger;

import org.ow2.orchestra.designer.fileNavigator.Navigator;
import org.ow2.orchestra.designer.fileNavigator.Process;
import org.ow2.orchestra.facade.AccessorUtil;
import org.ow2.orchestra.facade.ManagementAPI;
import org.ow2.orchestra.facade.def.ProcessDefinition;
import org.ow2.orchestra.facade.exception.OrchestraException;
import org.ow2.orchestra.util.Misc;

/**
 * Handles interaction between the designer and Orchestra engine.
 * @author Guillaume Porcher
 *
 */
public class OrchestraDeployer {

  private static final Logger LOG = Logger.getLogger(OrchestraDeployer.class.getName());

  private final Navigator fileNavigator = new Navigator();

  /**
   * Deploy the process to orchestra.
   * @param process process to deploy
   * @param jmxServiceUrl jmx service URL of Orchestra
   * @param objectName name of the JMX object for Orchestra APIs.
   * @return UUID of the deployed process
   * @throws OrchestraException
   * @throws IOException
   */
  public String deployToOrchestra(final Process process, final String jmxServiceUrl, final String objectName) throws OrchestraException, IOException {
    try {
      final byte[] barContent = this.fileNavigator.getExportedProcess(process);

      final ManagementAPI managementAPI = AccessorUtil.getManagementAPI(jmxServiceUrl, objectName);
      final ProcessDefinition processDefinition = managementAPI.deployBar(barContent);
      return processDefinition.getUUID().toString();
    } catch (final IOException e) {
      this.logException(e);
      throw e;
    } catch (final OrchestraException e) {
      this.logException(e);
      throw e;
    } catch (final RuntimeException e) {
      this.logException(e);
      throw e;
    }
  }

  private void logException(final Exception e) {
    e.printStackTrace();
    if (OrchestraDeployer.LOG.isLoggable(Level.FINE)) {
      Misc.fastDynamicLog(OrchestraDeployer.LOG, Level.FINE, "%s\n%s", e.getMessage(), Misc.getStackTraceFrom(e.getStackTrace()));
    } else {
      Misc.fastDynamicLog(OrchestraDeployer.LOG, Level.SEVERE, "%s", e.getMessage());
    }
  }
}

