/*******************************************************************************
 * Copyright (C) 2011  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 *******************************************************************************/

package org.ow2.orchestra.designer.server;

import java.io.Serializable;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.servlet.http.HttpSessionBindingEvent;
import javax.servlet.http.HttpSessionBindingListener;
import org.granite.context.GraniteContext;
import org.granite.messaging.webapp.HttpGraniteContext;

public class SessionsManager {
  protected static final Logger LOG = Logger.getLogger(SessionsManager.class.getName());

  /**
   * listening invalidation session
   */
  private class InvalidationSessionListener implements HttpSessionBindingListener, Serializable {
    private String user;

    public InvalidationSessionListener(String user) {
      this.user = user;
    }

    public void valueBound(HttpSessionBindingEvent arg0) {
      //nothing to do
    }

    /**
     * to execute if invalidation session : free the tokens Obtained by user
     *
     * @param arg0
     */
    public void valueUnbound(HttpSessionBindingEvent arg0) {
      SessionsManager.LOG.log(Level.INFO, "free tokens (invalidation session) by  : " + user);
      ConcurrentProcessesManager.getInstance().freeTokensObtainedByUser(user);

    }
  }

  public SessionsManager() {
  }

  /**
   * getting RemoteUser name which is contained in the Granite HttpRequest.<br/>
   * This method ensure that a user name will be return even if there is no currently
   * logged user, in this case the username will be "Anonymous". This is required for
   * testing purpose.
   *
   * @return Returns the name of the user currently logged for this request.
   */
  public String getUsername() {
    String username = "Anonymous";
    HttpGraniteContext graniteContext = (HttpGraniteContext) GraniteContext.getCurrentInstance();
    if (graniteContext != null) {
      username = graniteContext.getRequest().getRemoteUser();
      if (username == null) {
        username = "Anonymous";
      }

      if (graniteContext.getRequest().getSession().getAttribute(InvalidationSessionListener.class
          .getName()) == null) {
        graniteContext.getRequest().getSession().setAttribute(InvalidationSessionListener.class.getName(),
            new InvalidationSessionListener(username));
      }
    }

    return username;
  }

  /**
   * getting session id
   *
   * @return Returns the id of the current http session.
   */
  public String getSessionId() {
    return ((HttpGraniteContext) GraniteContext.getCurrentInstance()).getRequest().getSession(true).getId();
  }
}
