/*******************************************************************************
 * Copyright (C) 2011  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 *******************************************************************************/
package org.ow2.orchestra.designer.wsdlNavigator;

import java.io.ByteArrayInputStream;
import java.util.Map;
import java.util.logging.Level;
import javax.wsdl.xml.WSDLLocator;
import org.ow2.orchestra.util.Misc;
import org.xml.sax.InputSource;

/**
 * @author Guillaume Porcher
 */
public class Locator implements WSDLLocator {
  private Map<String, byte[]> files;
  private String wsdl;
  private String latest;

  public Locator(String wsdl, Map<String, byte[]> files) {
    this.wsdl = wsdl;
    this.files = files;
  }

  public InputSource getBaseInputSource() {
    return new InputSource(new ByteArrayInputStream(files.get(wsdl)));
  }

  public InputSource getImportInputSource(final String parent, final String resource) {
    Misc.slowLog(Level.FINEST, "getImportInputSource [parent=" + parent + ",resource=" + resource + "]");
    // An external URL
    if (resource.startsWith("http://") || resource.startsWith("https://")) {
      return new InputSource(resource);
    }
    // A file, get only file name and load from files map.
    final String fileName;
    if (resource.contains("/")) {
      fileName = resource.substring(resource.lastIndexOf("/") + 1);
    } else {
      fileName = resource;
    }
    latest = fileName;
    Misc.slowLog(Level.FINEST, "getImportInputSource [loading " + fileName + "]");
    byte[] resourceContent = files.get(fileName);
    if (resourceContent == null) {
      throw new ImportNotFoundException(fileName);
    }
    return new InputSource(new ByteArrayInputStream(resourceContent));
  }

  public String getBaseURI() {
    return wsdl;
  }

  public String getLatestImportURI() {
    return latest;
  }

  public void close() {
  }
}
